@@ -1,14 +1,14 @@
-from django.conf import settings
 from django.db.models import Q
+from django.db.models.query import QuerySet
 
 from django.contrib.sites.models import Site
 
 
-class EpisodeManager(object):
+class EpisodeManager(QuerySet):
     """Returns public episodes that are currently activated."""
 
     def itunespublished(self):
-        return self.get_query_set().exclude(Q(published=None) | Q(block=True))
+        return self.get_queryset().exclude(Q(published=None) | Q(block=True))
 
     def published(self):
         return self.exclude(published=None)
@@ -23,7 +23,7 @@ class EpisodeManager(object):
             return None
 
 
-class ShowManager(object):
+class ShowManager(QuerySet):
     """Returns shows that are on the current site."""
 
     def published(self):
